__defineBuiltinComponent('input', { js: function (BuiltinComponent, wx, mmp) {
            "use strict";

function compareVersion(a, b) {
  a = a.split('.');
  b = b.split('.');

  for (var i = 0; i < Math.max(a.length, b.length); i++) {
    var n1 = Number(a[i]) || 0;
    var n2 = Number(b[i]) || 0;
    if (n1 > n2) return 1;
    if (n1 < n2) return -1;
  }

  return 0;
}

function isVirtualMiniApp() {
  var global = typeof window === 'undefined' ? self : window;
  return global.__mmpSystemInfo && (global.__mmpSystemInfo.platform === 'devtools' || global.__mmpSystemInfo.isVirtualMiniApp);
}

function isNativeModeSupport() {
  var global = typeof window === 'undefined' ? self : window;

  if (isVirtualMiniApp()) {
    return false;
  }

  if (global.__mmpSystemInfo) {
    return compareVersion(global.__mmpSystemInfo.mmpSDKVersion, '1.9') >= 0;
  }

  return false;
}

BuiltinComponent('mt-input', {
  relations: {
    'mt-form': {
      type: 'ancestor'
    }
  },
  behaviors: ['wx://mt-form'],
  properties: {
    name: {
      type: String
    },
    type: {
      type: String,
      value: 'text'
    },
    value: {
      type: [String, Number],
      value: ''
    },
    password: {
      type: [Boolean, String],
      value: false
    },
    disabled: {
      type: Boolean,
      value: false
    },
    maxlength: {
      type: [Number, String],
      value: 140
    },
    cursorSpacing: {
      type: [Number, String],
      value: 0
    },
    autoFocus: {
      type: Boolean,
      value: false
    },
    focus: {
      type: Boolean,
      value: false
    },
    placeholder: {
      type: String,
      value: ''
    },
    placeholderStyle: {
      type: String,
      value: ''
    },
    placeholderClass: {
      type: String,
      value: ''
    },
    // 光标起始位置，自动聚集时有效，需与selection-end搭配使用
    selectionStart: {
      type: [Number, String],
      value: -1
    },
    // 光标结束位置，自动聚集时有效，需与selection-start搭配使用
    selectionEnd: {
      type: [Number, String],
      value: -1
    },
    // 键盘弹起时，是否自动上推页面
    adjustPosition: {
      type: Boolean,
      value: true
    },
    // 设置键盘右下角按钮的文字
    confirmType: {
      type: String,
      value: 'done'
    },
    // 点击键盘右下角按钮时是否保持键盘不收起
    confirmHold: {
      type: Boolean,
      value: false
    },
    // 指定focus时的光标位置
    cursor: {
      type: Number,
      value: -1
    }
  },
  events: [{
    name: 'tap',
    host: true,
    listener: 'handleTap'
  }],
  render: function render(h) {
    var inputOptions = {
      meta: {
        on: [{
          name: 'focus',
          host: true,
          listener: 'onFocus'
        }, {
          name: 'blur',
          host: true,
          listener: 'onBlur'
        }, {
          name: 'input',
          host: true,
          listener: 'onInput'
        }, {
          name: 'compositionstart',
          host: true,
          listener: 'onCompositionStart'
        }, {
          name: 'compositionend',
          host: true,
          listener: 'onCompositionEnd'
        }, {
          name: 'change',
          host: true,
          listener: 'onCompositionEnd'
        }, {
          name: 'keyup',
          host: true,
          listener: 'onKeyup'
        }],
        ref: 'input'
      },
      props: {
        name: this.data.name,
        type: this.data.password ? 'password' : this.data.type,
        maxlength: this.data.maxlength,
        value: this.data.value,
        disabled: this.data.disabled,
        readonly: isNativeModeSupport()
      }
    };

    if (isNativeModeSupport()) {
      inputOptions.props.type = this.data.password || this.data.type === 'password' ? 'password' : 'text';
      inputOptions.props['pointer-events'] = 'none';
    }

    if (this.data.type === 'number') {
      inputOptions.props.pattern = '[0-9]*';
    }

    if (this.data.type === 'digit') {
      inputOptions.props.type = 'text'; // eslint-disable-next-line

      inputOptions.props.pattern = '[0-9.]*';
    }

    var elements = [h('input', inputOptions)]; // placeholder

    elements.push(h('div', {
      meta: {
        ref: 'placeholder'
      }
    }));
    return elements;
  }
});
          } });